==> jei-1.21.5-fabric-21.3.2.24-sources.jar: mezz/jei/common/platform/IPlatformRenderHelper.java <==
package mezz.jei.common.platform;

import com.mojang.datafixers.util.Either;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;
import java.util.function.Function;
import net.minecraft.class_1011;
import net.minecraft.class_1058;
import net.minecraft.class_1293;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_4597;
import net.minecraft.class_5348;
import net.minecraft.class_5632;
import net.minecraft.class_6862;
import net.minecraft.class_8690;

public interface IPlatformRenderHelper {
	class_327 getFontRenderer(class_310 minecraft, class_1799 itemStack);

	boolean shouldRender(class_1293 potionEffect);

	Optional<class_1011> getMainImage(class_1058 sprite);

	void renderTooltip(class_332 guiGraphics, List<Either<class_5348, class_5632>> elements, int x, int y, class_327 font, class_1799 stack);

	class_2561 getName(class_6862<?> tagKey);

	class_4597 getBufferSource(class_332 guiGraphics);

	@Nullable
	class_1058 getTextureAtlasSprite(class_2680 blockState);

	void blitSprite(class_332 guiGraphics, Function<class_2960, class_1921> renderType, class_1058 sprite, int textureWidth, int textureHeight, int uPosition, int vPosition, int x, int y, int uWidth, int vHeight);

	void blitNineSlicedSprite(class_332 guiGraphics, Function<class_2960, class_1921> renderType, class_1058 sprite, class_8690.class_8691 scaling, int xOffset, int yOffset, int width, int height);

	void blitTiledSprite(class_332 guiGraphics, Function<class_2960, class_1921> renderType, class_1058 sprite, class_8690.class_8694 scaling, int xOffset, int yOffset, int width, int height, int color);
}

==> jei-1.21.10-fabric-26.1.1.25-sources.jar: mezz/jei/common/platform/IPlatformRenderHelper.java <==
package mezz.jei.common.platform;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import com.mojang.datafixers.util.Either;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;
import net.minecraft.class_1011;
import net.minecraft.class_1058;
import net.minecraft.class_1293;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_5348;
import net.minecraft.class_5632;
import net.minecraft.class_6862;
import net.minecraft.class_8690;

public interface IPlatformRenderHelper {
	class_327 getFontRenderer(class_310 minecraft, class_1799 itemStack);

	boolean shouldRender(class_1293 potionEffect);

	Optional<class_1011> getMainImage(class_1058 sprite);

	void renderTooltip(class_332 guiGraphics, List<Either<class_5348, class_5632>> elements, int x, int y, class_327 font, class_1799 stack);

	class_2561 getName(class_6862<?> tagKey);

	@Nullable
	class_1058 getTextureAtlasSprite(class_2680 blockState);

	void blitSprite(class_332 guiGraphics, RenderPipeline renderPipeline, class_1058 sprite, int textureWidth, int textureHeight, int uPosition, int vPosition, int x, int y, int uWidth, int vHeight);

	void blitNineSlicedSprite(class_332 guiGraphics, RenderPipeline renderPipeline, class_1058 sprite, class_8690.class_8691 scaling, int xOffset, int yOffset, int width, int height);

	void blitTiledSprite(class_332 guiGraphics, RenderPipeline renderPipeline, class_1058 sprite, class_8690.class_8694 scaling, int xOffset, int yOffset, int width, int height, int color);
}
